==> haskell-diff-0.4.0-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 Diff
version:              0.4.0
visibility:           public
id:                   Diff-0.4.0-2mjKm06J7q93AfCNNQ75Rh
key:                  Diff-0.4.0-2mjKm06J7q93AfCNNQ75Rh
license:              BSD-3-Clause
maintainer:           s.clover@gmail.com
author:               Sterling Clover
synopsis:             O(ND) diff algorithm in haskell.
description:
    Implementation of the standard diff algorithm, and utilities for pretty printing.

category:             Algorithms
abi:                  1eb899e39c9a7274fab7a41863e94fb7
exposed:              True
exposed-modules:
    Data.Algorithm.Diff Data.Algorithm.DiffContext
    Data.Algorithm.DiffOutput

import-dirs:          /usr/lib/ghc-8.8.3/site-local/Diff-0.4.0
library-dirs:         /usr/lib/ghc-8.8.3/site-local/Diff-0.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/Diff-0.4.0
hs-libraries:         HSDiff-0.4.0-2mjKm06J7q93AfCNNQ75Rh
depends:              array-0.5.4.0 base-4.13.0.0 pretty-1.1.3.6
haddock-interfaces:   /usr/share/doc/haskell-diff/html/Diff.haddock
haddock-html:         /usr/share/doc/haskell-diff/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-diff-0.4.0-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 Diff
version:              0.4.0
visibility:           public
id:                   Diff-0.4.0-KyPtUOKlpskC2b7jcuQ1e4
key:                  Diff-0.4.0-KyPtUOKlpskC2b7jcuQ1e4
license:              BSD-3-Clause
maintainer:           s.clover@gmail.com
author:               Sterling Clover
synopsis:             O(ND) diff algorithm in haskell.
description:
    Implementation of the standard diff algorithm, and utilities for pretty printing.

category:             Algorithms
abi:                  93d9f3b34e414a1b7635fc7415e47e33
exposed:              True
exposed-modules:
    Data.Algorithm.Diff Data.Algorithm.DiffContext
    Data.Algorithm.DiffOutput

import-dirs:          /usr/lib/ghc-8.10.2/site-local/Diff-0.4.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/Diff-0.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/Diff-0.4.0
hs-libraries:         HSDiff-0.4.0-KyPtUOKlpskC2b7jcuQ1e4
depends:              array-0.5.4.0 base-4.14.1.0 pretty-1.1.3.6
haddock-interfaces:   /usr/share/doc/haskell-diff/html/Diff.haddock
haddock-html:         /usr/share/doc/haskell-diff/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
